@@ -10,6 +10,7 @@ import pathlib
 import pprint
 import sys
 import time
+import unicodedata
 
 import click
 import yaml
@@ -22,7 +23,12 @@ from pathvalidate import (
 
 import osxphotos
 
-from ._constants import _EXIF_TOOL_URL, _PHOTOS_4_VERSION, _UNKNOWN_PLACE
+from ._constants import (
+    _EXIF_TOOL_URL,
+    _PHOTOS_4_VERSION,
+    _UNKNOWN_PLACE,
+    UNICODE_FORMAT,
+)
 from ._export_db import ExportDB, ExportDBInMemory
 from ._version import __version__
 from .datetime_formatter import DateTimeFormatter
@@ -40,10 +46,24 @@ OSXPHOTOS_EXPORT_DB = ".osxphotos_export.db"
 
 
 def verbose(*args, **kwargs):
+    """ print output if verbose flag set """
     if VERBOSE:
         click.echo(*args, **kwargs)
 
 
+def normalize_unicode(value):
+    """ normalize unicode data """
+    if value is not None:
+        if isinstance(value, tuple):
+            return tuple(unicodedata.normalize(UNICODE_FORMAT, v) for v in value)
+        elif isinstance(value, str):
+            return unicodedata.normalize(UNICODE_FORMAT, value)
+        else:
+            return value
+    else:
+        return None
+
+
 def get_photos_db(*db_options):
     """ Return path to photos db, select first non-None db_options
         If no db_options are non-None, try to find library to use in
@@ -592,9 +612,9 @@ def keywords(ctx, cli_obj, db, json_, photos_library):
     photosdb = osxphotos.PhotosDB(dbfile=db)
     keywords = {"keywords": photosdb.keywords_as_dict}
     if json_ or cli_obj.json:
-        click.echo(json.dumps(keywords))
+        click.echo(json.dumps(keywords, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(keywords, sort_keys=False))
+        click.echo(yaml.dump(keywords, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -621,9 +641,9 @@ def albums(ctx, cli_obj, db, json_, photos_library):
         albums["shared albums"] = photosdb.albums_shared_as_dict
 
     if json_ or cli_obj.json:
-        click.echo(json.dumps(albums))
+        click.echo(json.dumps(albums, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(albums, sort_keys=False))
+        click.echo(yaml.dump(albums, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -647,9 +667,9 @@ def persons(ctx, cli_obj, db, json_, photos_library):
     photosdb = osxphotos.PhotosDB(dbfile=db)
     persons = {"persons": photosdb.persons_as_dict}
     if json_ or cli_obj.json:
-        click.echo(json.dumps(persons))
+        click.echo(json.dumps(persons, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(persons, sort_keys=False))
+        click.echo(yaml.dump(persons, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -673,9 +693,9 @@ def labels(ctx, cli_obj, db, json_, photos_library):
     photosdb = osxphotos.PhotosDB(dbfile=db)
     labels = {"labels": photosdb.labels_as_dict}
     if json_ or cli_obj.json:
-        click.echo(json.dumps(labels))
+        click.echo(json.dumps(labels, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(labels, sort_keys=False))
+        click.echo(yaml.dump(labels, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -733,9 +753,9 @@ def info(ctx, cli_obj, db, json_, photos_library):
     info["persons"] = persons
 
     if cli_obj.json or json_:
-        click.echo(json.dumps(info))
+        click.echo(json.dumps(info, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(info, sort_keys=False))
+        click.echo(yaml.dump(info, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -783,9 +803,9 @@ def places(ctx, cli_obj, db, json_, photos_library):
     # below needed for to make CliRunner work for testing
     cli_json = cli_obj.json if cli_obj is not None else None
     if json_ or cli_json:
-        click.echo(json.dumps(places))
+        click.echo(json.dumps(places, ensure_ascii=False))
     else:
-        click.echo(yaml.dump(places, sort_keys=False))
+        click.echo(yaml.dump(places, sort_keys=False, allow_unicode=True))
 
 
 @cli.command()
@@ -848,7 +868,7 @@ def _list_libraries(json_=False, error=True):
             "system_library": sys_lib,
             "last_library": last_lib,
         }
-        click.echo(json.dumps(libs))
+        click.echo(json.dumps(libs, ensure_ascii=False))
     else:
         last_lib_flag = sys_lib_flag = False
 
@@ -1145,6 +1165,11 @@ def query(
     is_flag=True,
     help="Do not export edited version of photo if an edited version exists.",
 )
+@click.option(
+    "--skip-original-if-edited",
+    is_flag=True,
+    help="Do not export original if there is an edited version (exports only the edited version).",
+)
 @click.option(
     "--skip-bursts",
     is_flag=True,
@@ -1315,6 +1340,7 @@ def export(
     overwrite,
     export_by_date,
     skip_edited,
+    skip_original_if_edited,
     skip_bursts,
     skip_live,
     skip_raw,
@@ -1397,6 +1423,7 @@ def export(
         (export_as_hardlink, exiftool),
         (any(place), no_place),
         (deleted, deleted_only),
+        (skip_edited, skip_original_if_edited),
     ]
     if any(all(bb) for bb in exclusive):
         click.echo("Incompatible export options", err=True)
@@ -1564,6 +1591,7 @@ def export(
                     export_as_hardlink=export_as_hardlink,
                     overwrite=overwrite,
                     export_edited=export_edited,
+                    skip_original_if_edited=skip_original_if_edited,
                     original_name=original_name,
                     export_live=export_live,
                     download_missing=download_missing,
@@ -1604,6 +1632,7 @@ def export(
                         export_as_hardlink=export_as_hardlink,
                         overwrite=overwrite,
                         export_edited=export_edited,
+                        skip_original_if_edited=skip_original_if_edited,
                         original_name=original_name,
                         export_live=export_live,
                         download_missing=download_missing,
@@ -1635,7 +1664,6 @@ def export(
             photo_str_new = "photos" if len(results_new) != 1 else "photo"
             photo_str_updated = "photos" if len(results_updated) != 1 else "photo"
             photo_str_skipped = "photos" if len(results_skipped) != 1 else "photo"
-            photo_str_touched = "photos" if len(results_touched) != 1 else "photo"
             photo_str_exif_updated = (
                 "photos" if len(results_exif_updated) != 1 else "photo"
             )
@@ -1645,16 +1673,13 @@ def export(
                 f"skipped: {len(results_skipped)} {photo_str_skipped}, "
                 f"updated EXIF data: {len(results_exif_updated)} {photo_str_exif_updated}"
             )
-            if touch_file:
-                summary += f", touched date: {len(results_touched)} {photo_str_touched}"
-            click.echo(summary)
         else:
             photo_str = "photos" if len(results_exported) != 1 else "photo"
-            photo_str_touched = "photos" if len(results_touched) != 1 else "photo"
             summary = f"Exported: {len(results_exported)} {photo_str}"
-            if touch_file:
-                summary += f", touched date: {len(results_touched)} {photo_str_touched}"
-            click.echo(summary)
+        photo_str_touched = "photos" if len(results_touched) != 1 else "photo"
+        if touch_file:
+            summary += f", touched date: {len(results_touched)} {photo_str_touched}"
+        click.echo(summary)
         click.echo(f"Elapsed time: {(stop_time-start_time):.3f} seconds")
     else:
         click.echo("Did not find any photos to export")
@@ -1863,6 +1888,15 @@ def _query(
             to_date=to_date,
         )
 
+    person = normalize_unicode(person)
+    keyword = normalize_unicode(keyword)
+    album = normalize_unicode(album)
+    folder = normalize_unicode(folder)
+    title = normalize_unicode(title)
+    description = normalize_unicode(description)
+    place = normalize_unicode(place)
+    label = normalize_unicode(label)
+
     if album:
         photos = get_photos_by_attribute(photos, "albums", album, ignore_case)
 
@@ -2087,6 +2121,7 @@ def export_photo(
     export_as_hardlink=None,
     overwrite=None,
     export_edited=None,
+    skip_original_if_edited=None,
     original_name=None,
     export_live=None,
     download_missing=None,
@@ -2125,6 +2160,8 @@ def export_photo(
         filename_template: template use to determine output file
         no_extended_attributes: boolean; if True, exports photo without preserving extended attributes
         export_raw: boolean; if True exports RAW image associate with the photo
+        export_edited: boolean; if True exports edited version of photo if there is one
+        skip_original_if_edited: boolean; if True does not export original if photo has been edited
         album_keyword: boolean; if True, exports album names as keywords in metadata
         person_keyword: boolean; if True, exports person names as keywords in metadata
         keyword_template: list of strings; if provided use rendered template strings as keywords
@@ -2147,18 +2184,18 @@ def export_photo(
     if not download_missing:
         if photo.ismissing:
             space = " " if not verbose_ else ""
-            verbose(f"{space}Skipping missing photo {photo.filename}")
+            verbose(f"{space}Skipping missing photo {photo.original_filename}")
             return ExportResults([], [], [], [], [], [])
         elif not os.path.exists(photo.path):
             space = " " if not verbose_ else ""
             verbose(
                 f"{space}WARNING: file {photo.path} is missing but ismissing=False, "
-                f"skipping {photo.filename}"
+                f"skipping {photo.original_filename}"
             )
             return ExportResults([], [], [], [], [], [])
     elif photo.ismissing and not photo.iscloudasset or not photo.incloud:
         verbose(
-            f"Skipping missing {photo.filename}: not iCloud asset or missing from cloud"
+            f"Skipping missing {photo.original_filename}: not iCloud asset or missing from cloud"
         )
         return ExportResults([], [], [], [], [], [])
 
@@ -2169,9 +2206,11 @@ def export_photo(
     results_exif_updated = []
     results_touched = []
 
+    export_original = not (skip_original_if_edited and photo.hasadjustments)
+
     filenames = get_filenames_from_template(photo, filename_template, original_name)
     for filename in filenames:
-        verbose(f"Exporting {photo.filename} as {filename}")
+        verbose(f"Exporting {photo.original_filename} ({photo.filename}) as {filename}")
 
         dest_paths = get_dirnames_from_template(
             photo, directory, export_by_date, dest, dry_run
@@ -2194,47 +2233,50 @@ def export_photo(
 
         # export the photo to each path in dest_paths
         for dest_path in dest_paths:
-            export_results = photo.export2(
-                dest_path,
-                filename,
-                sidecar_json=sidecar_json,
-                sidecar_xmp=sidecar_xmp,
-                live_photo=export_live,
-                raw_photo=export_raw,
-                export_as_hardlink=export_as_hardlink,
-                overwrite=overwrite,
-                use_photos_export=use_photos_export,
-                exiftool=exiftool,
-                no_xattr=no_extended_attributes,
-                use_albums_as_keywords=album_keyword,
-                use_persons_as_keywords=person_keyword,
-                keyword_template=keyword_template,
-                description_template=description_template,
-                update=update,
-                export_db=export_db,
-                fileutil=fileutil,
-                dry_run=dry_run,
-                touch_file=touch_file,
-            )
+            if not export_original:
+                verbose(f"Skipping original version of {photo.original_filename}")
+            else:
+                export_results = photo.export2(
+                    dest_path,
+                    filename,
+                    sidecar_json=sidecar_json,
+                    sidecar_xmp=sidecar_xmp,
+                    live_photo=export_live,
+                    raw_photo=export_raw,
+                    export_as_hardlink=export_as_hardlink,
+                    overwrite=overwrite,
+                    use_photos_export=use_photos_export,
+                    exiftool=exiftool,
+                    no_xattr=no_extended_attributes,
+                    use_albums_as_keywords=album_keyword,
+                    use_persons_as_keywords=person_keyword,
+                    keyword_template=keyword_template,
+                    description_template=description_template,
+                    update=update,
+                    export_db=export_db,
+                    fileutil=fileutil,
+                    dry_run=dry_run,
+                    touch_file=touch_file,
+                )
 
-            results_exported.extend(export_results.exported)
-            results_new.extend(export_results.new)
-            results_updated.extend(export_results.updated)
-            results_skipped.extend(export_results.skipped)
-            results_exif_updated.extend(export_results.exif_updated)
-            results_touched.extend(export_results.touched)
+                results_exported.extend(export_results.exported)
+                results_new.extend(export_results.new)
+                results_updated.extend(export_results.updated)
+                results_skipped.extend(export_results.skipped)
+                results_exif_updated.extend(export_results.exif_updated)
+                results_touched.extend(export_results.touched)
 
-            if verbose_:
-                for exported in export_results.exported:
-                    verbose(f"Exported {exported}")
-                for new in export_results.new:
-                    verbose(f"Exported new file {new}")
-                for updated in export_results.updated:
-                    verbose(f"Exported updated file {updated}")
-                for skipped in export_results.skipped:
-                    verbose(f"Skipped up to date file {skipped}")
-                for touched in export_results.touched:
-                    verbose(f"Touched date on file {touched}")
+                if verbose_:
+                    for exported in export_results.exported:
+                        verbose(f"Exported {exported}")
+                    for new in export_results.new:
+                        verbose(f"Exported new file {new}")
+                    for updated in export_results.updated:
+                        verbose(f"Exported updated file {updated}")
+                    for skipped in export_results.skipped:
+                        verbose(f"Skipped up to date file {skipped}")
+                    for touched in export_results.touched:
+                        verbose(f"Touched date on file {touched}")
 
             # if export-edited, also export the edited version
             # verify the photo has adjustments and valid path to avoid raising an exception
