@@ -106,7 +106,7 @@ def _export_photo_uuid_applescript(
     )
 
     dest = pathlib.Path(dest)
-    if not dest.is_dir:
+    if not dest.is_dir():
         raise ValueError(f"dest {dest} must be a directory")
 
     if not original ^ edited:
@@ -629,7 +629,7 @@ def export2(
                 logging.debug(f"Skipping missing RAW photo for {filename}")
     else:
         # use_photo_export
-        exported = [] 
+        exported = []
         # export live_photo .mov file?
         live_photo = True if live_photo and self.live_photo else False
         if edited:
@@ -677,18 +677,15 @@ def export2(
             exported_files.extend(exported)
             if update:
                 update_new_files.extend(exported)
-                    
+
         else:
             logging.warning(
                 f"Error exporting photo {self.uuid} to {dest} with use_photos_export"
             )
 
-    # export metadata
-    info = export_db.get_info_for_uuid(self.uuid)
-
     if sidecar_json:
         logging.debug("writing exiftool_json_sidecar")
-        sidecar_filename = dest.parent / pathlib.Path(f"{dest.stem}.json")
+        sidecar_filename = dest.parent / pathlib.Path(f"{dest.stem}{dest.suffix}.json")
         sidecar_str = self._exiftool_json_sidecar(
             use_albums_as_keywords=use_albums_as_keywords,
             use_persons_as_keywords=use_persons_as_keywords,
@@ -704,12 +701,13 @@ def export2(
 
     if sidecar_xmp:
         logging.debug("writing xmp_sidecar")
-        sidecar_filename = dest.parent / pathlib.Path(f"{dest.stem}.xmp")
+        sidecar_filename = dest.parent / pathlib.Path(f"{dest.stem}{dest.suffix}.xmp")
         sidecar_str = self._xmp_sidecar(
             use_albums_as_keywords=use_albums_as_keywords,
             use_persons_as_keywords=use_persons_as_keywords,
             keyword_template=keyword_template,
             description_template=description_template,
+            extension=dest.suffix[1:] if dest.suffix else None,
         )
         if not dry_run:
             try:
@@ -796,9 +794,9 @@ def export2(
 
     if touch_file:
         for exif_file in exif_files_updated:
-            touched_files.append(exported_file)
+            touched_files.append(exif_file)
             ts = int(self.date.timestamp())
-            fileutil.utime(exported_file, (ts, ts))
+            fileutil.utime(exif_file, (ts, ts))
 
     touched_files = list(set(touched_files))
 
@@ -1120,6 +1118,7 @@ def _xmp_sidecar(
     use_persons_as_keywords=False,
     keyword_template=None,
     description_template=None,
+    extension=None,
 ):
     """ returns string for XMP sidecar 
         use_albums_as_keywords: treat album names as keywords
@@ -1127,10 +1126,12 @@ def _xmp_sidecar(
         keyword_template: (list of strings); list of template strings to render as keywords 
         description_template: string; optional template string that will be rendered for use as photo description """
 
-    # TODO: add additional fields to XMP file?
-
     xmp_template = Template(filename=os.path.join(_TEMPLATE_DIR, _XMP_TEMPLATE_NAME))
 
+    if extension is None:
+        extension = pathlib.Path(self.original_filename)
+        extension = extension.suffix[1:] if extension.suffix else None
+
     if description_template is not None:
         description = self.render_template(
             description_template, expand_inplace=True, inplace_sep=", "
@@ -1199,6 +1200,7 @@ def _xmp_sidecar(
         keywords=keyword_list,
         persons=person_list,
         subjects=subject_list,
+        extension=extension,
     )
 
     # remove extra lines that mako inserts from template
