@@ -5,16 +5,12 @@ PhotosDB.photos() returns a list of PhotoInfo objects
 """
 
 import dataclasses
-import glob
 import json
 import logging
 import os
 import os.path
 import pathlib
-import subprocess
-import sys
 from datetime import timedelta, timezone
-from pprint import pformat
 
 import yaml
 
@@ -25,11 +21,12 @@ from .._constants import (
     _PHOTOS_4_ROOT_FOLDER,
     _PHOTOS_4_VERSION,
     _PHOTOS_5_ALBUM_KIND,
+    _PHOTOS_5_IMPORT_SESSION_ALBUM_KIND,
     _PHOTOS_5_SHARED_ALBUM_KIND,
     _PHOTOS_5_SHARED_PHOTO_PATH,
 )
-from ..albuminfo import AlbumInfo
-from ..personinfo import PersonInfo
+from ..albuminfo import AlbumInfo, ImportInfo
+from ..personinfo import FaceInfo, PersonInfo
 from ..phototemplate import PhotoTemplate
 from ..placeinfo import PlaceInfo4, PlaceInfo5
 from ..utils import _debug, _get_resource_loc, findfiles, get_preferred_uti_extension
@@ -87,11 +84,7 @@ class PhotoInfo:
     @property
     def date(self):
         """ image creation date as timezone aware datetime object """
-        imagedate = self._info["imageDate"]
-        seconds = self._info["imageTimeZoneOffsetSeconds"] or 0
-        delta = timedelta(seconds=seconds)
-        tz = timezone(delta)
-        return imagedate.astimezone(tz=tz)
+        return self._info["imageDate"]
 
     @property
     def date_modified(self):
@@ -353,6 +346,20 @@ class PhotoInfo:
             ]
             return self._personinfo
 
+    @property
+    def face_info(self):
+        """ list of FaceInfo objects for faces in picture """
+        try:
+            return self._faceinfo
+        except AttributeError:
+            try:
+                faces = self._db._db_faceinfo_uuid[self._uuid]
+                self._faceinfo = [FaceInfo(db=self._db, pk=pk) for pk in faces]
+            except KeyError:
+                # no faces
+                self._faceinfo = []
+            return self._faceinfo
+
     @property
     def albums(self):
         """ list of albums picture is contained in """
@@ -377,6 +384,19 @@ class PhotoInfo:
             ]
             return self._album_info
 
+    @property
+    def import_info(self):
+        """ ImportInfo object representing import session for the photo or None if no import session """
+        try:
+            return self._import_info
+        except AttributeError:
+            self._import_info = (
+                ImportInfo(db=self._db, uuid=self._info["import_uuid"])
+                if self._info["import_uuid"] is not None
+                else None
+            )
+            return self._import_info
+
     @property
     def keywords(self):
         """ list of keywords for picture """
@@ -735,7 +755,7 @@ class PhotoInfo:
         """ Return list of album UUIDs this photo is found in
         
             Filters out albums in the trash and any special album types
-        
+
         Returns: list of album UUIDs 
         """
         if self._db._db_version <= _PHOTOS_4_VERSION:
